@@ -1,14 +1,14 @@
 #
 # This file is part of Config-Model-TkUI
 #
-# This software is Copyright (c) 2008-2016 by Dominique Dumont.
+# This software is Copyright (c) 2008-2017 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Tk::LeafEditor;
-$Config::Model::Tk::LeafEditor::VERSION = '1.359';
+$Config::Model::Tk::LeafEditor::VERSION = '1.364';
 use strict;
 use warnings;
 use Carp;
@@ -42,6 +42,7 @@ sub Populate {
         || die "LeafEditor: no -item, got ", keys %$args;
     delete $args->{-path};
     $cw->{store_cb} = delete $args->{-store_cb} || die __PACKAGE__, "no -store_cb";
+    my $cme_font = delete $args->{-font};
 
     my $inst = $leaf->instance;
     my $vt   = $leaf->value_type;
@@ -131,6 +132,7 @@ sub Populate {
     $cw->set_value_help;
 
     $cw->ConfigSpecs(
+        -font => [['SELF','DESCENDANTS'], 'font','Font', $cme_font ],
 
         #-fill   => [ qw/SELF fill Fill both/],
         #-expand => [ qw/SELF expand Expand 1/],
@@ -216,6 +218,7 @@ sub try {
         $cw->Dialog(
             -title => 'Value error',
             -text  => join( "\n", @errors ),
+            -font => scalar $cw->cget('-font'),
         )->Show;
         $cw->reset_value;
         return;
@@ -268,6 +271,7 @@ sub store {
         $cw->Dialog (
             -title => 'Value error',
             -text  => $@->as_string,
+            -font => scalar $cw->cget('-font'),
         )->Show;
         $cw->reset_value;
     }
@@ -275,6 +279,7 @@ sub store {
         $cw->Dialog (
             -title => 'Value error',
             -text  => "Cannot store the value:\n* ".join("\n* ",$leaf->all_errors),
+            -font => scalar $cw->cget('-font'),
         )->Show;
         $cw->reset_value;
     }
@@ -318,8 +323,20 @@ sub reset_value {
 sub exec_external_editor {
     my $cw = shift;
 
-    # the .pod suffix let the editor use the correct mode
-    my $pt = Path::Tiny->tempfile(SUFFIX => '.pod');
+    my @pt_args;
+
+    # ugly hack to use pod mode only for Model description parameter
+    # i.e. for 'cme meta edit;
+    my $leaf = $cw->{leaf};
+    if ($leaf->parent->config_class_name =~ /^Itself/ and
+            $leaf->element_name =~ /description/
+        ) {
+        # the .pod suffix let the editor use the correct mode
+        @pt_args = (SUFFIX => '.pod');
+    }
+
+    my $pt = Path::Tiny->tempfile(@pt_args);
+
     die "Can't create Path::Tiny:$!" unless defined $pt;
     $pt->spew_utf8( $cw->{e_widget}->get( '1.0', 'end' ) );
 
@@ -334,6 +351,7 @@ sub exec_external_editor {
         $cw->Dialog(
             -title => 'External editor error',
             -text  => "'$ed' : $!",
+            -font => scalar $cw->cget('-font'),
         )->Show;
         return;
     }
